Learn R Programming

lfproQC (version 1.4.1)

rlr_knn_yeast_data: Normalized and imputed complete yeast lysate - UPS1 benchmark dataset

Description

This is the groupwise normalized and missing values imputed dataset of the complete yeast lysate - UPS1 benchmark dataset. Normalization has been done by RLR normalization method and missing values imputation has been done by KNN imputation method.

Usage

rlr_knn_yeast_data

Arguments

Format

A data frame with 835 rows and 7 variables:

Majority protein IDs

Protein ID information

A1

1st sample group, 1st technical replicate

A2

1st sample group, 2nd technical replicate

A3

1st sample group, 3rd technical replicate

B1

2nd sample group, 1st technical replicate

B2

2nd sample group, 2nd technical replicate

B3

2nd sample group, 3rd technical replicate