Learn R Programming

lfproQC (version 1.4.1)

volcanoplot_DE_fn: Find out the Up and Down regulated proteins from volcano plot

Description

Volcano plot is used for visualizing the differentially expressed proteins by plotting the log fold change values in x axis and (-log10 p-values) in y axis.

This function can be used for visualizing the up regulated, down regulated, and non-significant proteins along with their information.

Usage

volcanoplot_DE_fn(top_table, x1 = NULL, x2 = NULL, p = NULL)

Value

`Result` Top table along with up, down, significant and non-significant protein information.

`Volcano plot` Interactive MA plot with the details of up and down regulated proteins

`Up-regulated` Up-regulated protein information

`Down-regulated` Down-regulated protein information

`Non-significant` Non-significant protein information

Arguments

top_table

Top table information

x1

Cut-off limit for down-regulated proteins

x2

Cut-off limit for up-regulated proteins

p

Cut-off limit for p-values

Examples

Run this code
result <- volcanoplot_DE_fn(yeast_top_table, -1, 1, 0.05)
result$`Volcano Plot`
result$`Result`
result$`Up-regulated`
result$`Down-regulated`
result$`Non-significant`

Run the code above in your browser using DataLab