This is the groupwise normalized and missing values imputed dataset of the complete yeast lysate - UPS1 benchmark dataset. Normalization has been done by RLR normalization method and missing values imputation has been done by KNN imputation method.
rlr_knn_yeast_dataA data frame with 835 rows and 7 variables:
Protein ID information
1st sample group, 1st technical replicate
1st sample group, 2nd technical replicate
1st sample group, 3rd technical replicate
2nd sample group, 1st technical replicate
2nd sample group, 2nd technical replicate
2nd sample group, 3rd technical replicate