volcanoplot_DE_fn: Find out the Up and Down regulated proteins from volcano plot
Description
Volcano plot is used for visualizing the differentially expressed proteins by plotting the log fold change values in x axis and (-log10 p-values) in y axis.
This function can be used for visualizing the up regulated, down regulated, and non-significant proteins along with their information.
Usage
volcanoplot_DE_fn(top_table, x1 = NULL, x2 = NULL, p = NULL)
Value
`Result` Top table along with up, down, significant and non-significant protein information.
`Volcano plot` Interactive MA plot with the details of up and down regulated proteins
`Up-regulated` Up-regulated protein information
`Down-regulated` Down-regulated protein information
`Non-significant` Non-significant protein information